otcextensions.sdk.apig.v2.api_call
==================================

.. automodule:: otcextensions.sdk.apig.v2.api_call

The ApiCallResult Class
-----------------------
The ``ApiCallResult`` class inherits from
:class:`~otcextensions.sdk.sdk_resource.Resource`.

.. autoclass:: otcextensions.sdk.apig.v2.api_call.ApiCallResult
   :members:
